@@ -14,7 +14,7 @@ class BaseApi:
     header = {'Content-Type': 'application/json'}
     api_url = "https://oneapilite.azurewebsites.net/api"
 
-    def update_token(self, token):
+    def update_token(self, token: str) -> None:
         """
         Atualiza o token de acesso
         """
@@ -23,60 +23,60 @@ class BaseApi:
             'Authorization': f'Bearer {token}'
         }
 
-    def post(self, url, data):
+    def post(self, url: str, data: dict) -> requests.Response:
         """
         Post request, URL base já inclusa
         """
         try:
-            return requests.post("{}{}".format(self.api_url, url),
+            return requests.post(f"{self.api_url}{url}",
                                  headers=self.header,
                                  data=json.dumps(data))
         except requests.exceptions.ConnectionError:
             sys.exit("\nConnection error!!\nCheck your internet connection")
 
-    def get(self, url):
+    def get(self, url: str) -> requests.Response:
         """
         Get request, URL base já inclusa
         """
         try:
-            return requests.get("{}{}".format(self.api_url, url),
-                                headers=self.header)
+            return requests.get(f"{self.api_url}{url}", headers=self.header)
         except requests.exceptions.ConnectionError:
             sys.exit("\nConnection error!!\nCheck your internet connection")
 
-    def delete(self, url):
+    def delete(self, url: str) -> requests.Response:
         """
         Delete request, URL base já inclusa
         """
         try:
-            return requests.delete("{}{}".format(self.api_url, url),
-                                   headers=self.header)
+            return requests.delete(f"{self.api_url}{url}", headers=self.header)
         except requests.exceptions.ConnectionError:
             sys.exit("\nConnection error!!\nCheck your internet connection")
 
-    def put(self, url, data):
+    def put(self, url: str, data: dict) -> requests.Response:
         """
         Put request, URL base já inclusa
         """
         try:
-            return requests.put("{}{}".format(self.api_url, url),
+            return requests.put(f"{self.api_url}{url}",
                                 headers=self.header,
                                 data=json.dumps(data))
         except requests.exceptions.ConnectionError:
             sys.exit("\nConnection error!!\nCheck your internet connection")
 
-    def patch(self, url, data):
+    def patch(self, url: str, data: dict) -> requests.Response:
         """
         Patch requests, URL base já inclusa
         """
         try:
-            return requests.patch("{}{}".format(self.api_url, url),
+            return requests.patch(f"{self.api_url}{url}",
                                   headers=self.header,
                                   data=json.dumps(data))
         except requests.exceptions.ConnectionError:
             sys.exit("\nConnection error!!\nCheck your internet connection")
 
-    def status_ok(self, response, erro_exit=True):
+    def status_ok(self,
+                  response: requests.Response,
+                  erro_exit: bool = True) -> bool:
         """
         verifica se e requisição foi feita com sucesso (200),
         por padrão se a requisição falhou o programa é encerrado,
@@ -84,8 +84,8 @@ class BaseApi:
         """
         if not response.ok:
             print(f'Erro code: {response.status_code}')
-            print(response.content)
+            print(response.text)
             if erro_exit:
-                sys.exit()
+                sys.exit(1)
             return False
         return True
